@@ -13,7 +13,6 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-import mock
 import pytest
 import ccxt.async_support
 import trading_backend.exchanges as exchanges
@@ -22,7 +21,7 @@ from tests import bitget_exchange
 
 
 def test_get_name(bitget_exchange):
-    assert exchanges.Bitget(bitget_exchange).get_name() == ccxt.async_support.bitget().name.lower()
+    assert exchanges.Bitget(bitget_exchange).get_name() == ccxt.async_support.bitget().id.lower()
 
 
 @pytest.mark.asyncio
@@ -30,6 +29,16 @@ async def test_get_orders_parameters(bitget_exchange):
     exchange = exchanges.Bitget(bitget_exchange)
     await create_order_tests.create_order_mocked_test_args(
         exchange,
-        exchange_private_post_order_method_name="privateSpotPostTradeOrders",
-        exchange_request_referral_key="clientOrderId",
+        exchange_private_post_order_method_name="privateSpotPostV2SpotTradePlaceOrder",
+        exchange_request_referral_key="clientOid",
         should_contains=True)
+
+
+@pytest.mark.asyncio
+async def test_sign(bitget_exchange):
+    exchange = exchanges.Bitget(bitget_exchange)
+    await create_order_tests.sign_test(
+        exchange,
+        ["private", "spot"],
+        "X-CHANNEL-API-CODE",
+    )
