@@ -13,8 +13,6 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
-VERSION = "1.0.19"
-PROJECT_NAME = "trading-backend"
 
 from trading_backend import exchange_factory
 from trading_backend.exchange_factory import (
@@ -25,6 +23,9 @@ from trading_backend import errors
 from trading_backend.errors import (
     TimeSyncError,
     ExchangeAuthError,
+    APIKeyIPWhitelistError,
+    APIKeyPermissionsError,
+    UnexpectedError,
 )
 
 __all__ = [
@@ -32,4 +33,7 @@ __all__ = [
     "is_sponsoring",
     "TimeSyncError",
     "ExchangeAuthError",
+    "APIKeyIPWhitelistError",
+    "APIKeyPermissionsError",
+    "UnexpectedError",
 ]
