@@ -15,9 +15,25 @@
 #  License along with this library.
 
 
-class TimeSyncError(RuntimeError):
+class UnexpectedError(RuntimeError):
+    pass
+
+
+class TimeSyncError(UnexpectedError):
     pass
 
 
 class ExchangeAuthError(RuntimeError):
     pass
+
+
+class APIKeyIPWhitelistError(ExchangeAuthError):
+    pass
+
+
+class APIKeyPermissionsError(ExchangeAuthError):
+    pass
+
+
+class InvalidIdError(RuntimeError):
+    pass
